summaryrefslogtreecommitdiff
path: root/sysui/util/checksize.pl
diff options
context:
space:
mode:
Diffstat (limited to 'sysui/util/checksize.pl')
-rw-r--r--sysui/util/checksize.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/sysui/util/checksize.pl b/sysui/util/checksize.pl
index ea0def46d5b5..808442d91a18 100644
--- a/sysui/util/checksize.pl
+++ b/sysui/util/checksize.pl
@@ -82,8 +82,8 @@ sub check #04.02.2005 13:40
my $path = shift;
my $file = shift;
print "$path$file\n" if ((-e "$path$file") && $is_debug);
- # don't check dpc,flag,rpmflag, [obj for UNX] files, or etc subdirectory
- return if ( ($file =~ /.+\.(dpc|\w*?flag)/) || ($file =~ /.+\.obj/ && $ENV{GUI} eq 'UNX') || ($path =~ /.+etc/) || ($path =~ /.+logs/) );
+ # don't check dpc,flag,rpmflag,sdf [obj for UNX] files, or etc subdirectory
+ return if ( ($file =~ /.+\.(dpc|\w*?flag)/) || ($file =~ /.+\.obj/ && $ENV{GUI} eq 'UNX') || ($path =~ /.+etc/) || ($path =~ /.+logs/) || ($path =~ /.+sdf/) );
if ( -z "$path$file" ) {
print "Error: $path$file 0 Bytes!\n";
$err++;